@@ -6,11 +6,11 @@ moran.plot <- function(x, listw, zero.policy=NULL, spChk=NULL,
 {
 	if (!inherits(listw, "listw")) stop(paste(deparse(substitute(listw)),
 		"is not a listw object"))
-        if (is.null(quiet)) quiet <- !get("verbose", env = .spdepOptions)
+        if (is.null(quiet)) quiet <- !get("verbose", envir = .spdepOptions)
         stopifnot(is.vector(x))
         stopifnot(is.logical(quiet))
         if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", env = .spdepOptions)
+            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
         stopifnot(is.logical(zero.policy))
 	xname <- deparse(substitute(x))
 	if (!is.numeric(x)) stop(paste(xname, "is not a numeric vector"))
